import LynkElement from '../../internal/lynk-element.js';
import LynkIconButton from '../icon-button/icon-button.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Alerts are used to display important messages inline or as toast notifications.
 * @documentation https://lynk.design/components/alert
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon-button
 *
 * @slot - The alert's content.
 * @slot icon - An icon to show in the alert.
 * @slot action - Append custom actions to alert.
 *
 * @event ev-show - Emitted when the alert opens.
 * @event ev-after-show - Emitted after the alert opens and all animations are complete.
 * @event ev-hide - Emitted when the alert closes.
 * @event ev-after-hide - Emitted after the alert closes and all animations are complete.
 *
 * @csspart base - The component's internal block wrapper.
 * @csspart icon - The container that wraps the alert icon.
 * @csspart message - The alert message.
 * @csspart close-button - The close button.
 * @csspart close-button__base - The close button's `base` part.
 *
 * @cssproperty --box-shadow - The alert's box shadow.
 * @cssproperty --padding - The top and bottom padding of the message. Use any spacing token (--lynk-spacing-large) or a custom value.
 *
 * @animation alert.show - The animation to use when showing the alert.
 * @animation alert.hide - The animation to use when hiding the alert.
 */
export default class LynkAlert extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon-button': typeof LynkIconButton;
    };
    private autoHideTimeout;
    private remainingTimeInterval;
    private countdownAnimation?;
    private readonly hasSlotController;
    private readonly localize;
    base: HTMLElement;
    countdownElement: HTMLElement;
    /** Indicates whether or not the alert is open. You can use this in lieu of the show/hide methods. */
    open: boolean;
    /** Makes the alert closable. */
    closable: boolean;
    /** The alert's type (color). */
    type: 'primary' | 'info' | 'success' | 'neutral' | 'warning' | 'danger';
    /**
     * The length of time, in milliseconds, the alert will show before closing itself. If the user interacts with
     * the alert before it closes (e.g. moves the mouse over it), the timer will restart. Defaults to `Infinity`.
     */
    duration: number;
    /**
     * Enables a countdown that indicates the remaining time the alert will be displayed.
     * Typically used to indicate the remaining time before a whole app refresh.
     */
    countdown?: 'rtl' | 'ltr';
    private remainingTime;
    firstUpdated(): void;
    private restartAutoHide;
    private pauseAutoHide;
    private resumeAutoHide;
    private handleCountdownChange;
    private handleCloseClick;
    handleOpenChange(): Promise<void>;
    handleDurationChange(): void;
    /** Shows the alert. */
    show(): Promise<void>;
    /** Hides the alert */
    hide(): Promise<void>;
    /**
     * Displays the alert as a toast notification. This will move the alert out of its position in the DOM and, when
     * dismissed, it will be removed from the DOM completely. By storing a reference to the alert, you can reuse it by
     * calling this method again. The returned promise will resolve after the alert is hidden.
     */
    toast(): Promise<void>;
    render(): import("lit").TemplateResult<1>;
}
