import LynkButton from '../button/button.component.js';
import LynkElement from '../../internal/lynk-element.js';
import LynkTooltip from '../tooltip/tooltip.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary The Page Sidebar is used inside a [Page Layout](/components/page) to render navigation and selection menus, or other related content that would normally be placed in a native `<aside>` element.
 * @documentation https://lynk.design/components/page-sidebar
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-button
 * @dependency lynk-tooltip
 *
 * @slot - The sidebar's content.
 * @slot label - The sidebar's label. Alternatively, you can use the label prop.
 * @slot footer - The sidebar's footer, usually one or more buttons representing various options.
 * @slot nav - An optional slot that can be used to display nav controls even when sidebar is collapsed.
 *
 * @event ev-show - Emitted when the sidebar opens.
 * @event ev-after-show - Emitted after the sidebar opens and all animations are complete.
 * @event ev-hide - Emitted when the sidebar closes.
 * @event ev-after-hide - Emitted after the sidebar closes and all animations are complete.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart panel - The sidebar panel (where the sidebar and its content is rendered).
 * @csspart header - The sidebar header.
 * @csspart header-actions - Optional actions to add to the header. Works best with `<lynk-icon-button>`.
 * @csspart title - The sidebar title.
 * @csspart close-button - The close button.
 * @csspart close-button__base - The close button's `base` part.
 * @csspart body - The sidebar body.
 * @csspart footer - The sidebar footer.
 * @csspart nav - The optional sidebar nav do display controls even when the sidebar is collapsed.
 *
 * @cssproperty --width - The preferred width of the sidebar.
 * @cssproperty --header-spacing - The amount of padding to use for the header.
 * @cssproperty --body-spacing - The amount of padding to use for the body.
 * @cssproperty --footer-spacing - The amount of padding to use for the footer.
 */
export default class LynkPageSidebar extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-button': typeof LynkButton;
        'lynk-tooltip': typeof LynkTooltip;
    };
    sidebar: HTMLElement;
    container: HTMLElement;
    body: HTMLElement;
    header: HTMLElement;
    footer: HTMLElement;
    tooltip: LynkTooltip;
    private readonly hasSlotController;
    private readonly localize;
    /** Indicates whether or not the sidebar is open. You can use this in lieu of the show/hide methods. */
    open: boolean;
    /**
     * The sidebar optional heading as displayed in the header. If you need to display HTML, you can use the `header` slot instead.
     */
    heading?: string;
    /** The placement of the sidebar in the page layout */
    placement: 'left' | 'right' | 'left-inset' | 'right-inset';
    /** Choose if the toggle functionality collapses the contents, hides the sidebar entirely, or is disabled  */
    toggle: 'contents' | 'visibility' | 'none';
    /** Choose placement of toggle button when toggling contents  */
    togglePlacement: 'top' | 'center' | 'bottom' | 'hidden';
    /** Customize toggle contents tooltip text  */
    toggleTipHideText: string;
    toggleTipShowText: string;
    connectedCallback(): void;
    firstUpdated(): void;
    /** Shows the sidebar */
    show(): Promise<void>;
    /** Hides the sidebar */
    hide(): Promise<void>;
    private hasParentLayout;
    private handleToggleClick;
    private updateVisibility;
    handleOpenChange(): void;
    render(): import("lit").TemplateResult<1>;
}
