import { FormControlController } from '../../internal/form.js';
import LynkButtonGroup from '../button-group/button-group.component.js';
import LynkElement from '../../internal/lynk-element.js';
import LynkTooltip from '../tooltip/tooltip.component.js';
import type { CSSResultGroup } from 'lit';
import type { LynkFormControl } from '../../internal/lynk-element.js';
/**
 * @summary Radio groups are used to group multiple [radios](/components/radio) or [radio buttons](/components/radio-button) so they function as a single form control.
 * @documentation https://lynk.design/components/radio-group
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-button-group
 * @dependency lynk-tooltip
 *
 * @slot - The default slot where `<lynk-radio>` or `<lynk-radio-button>` elements are placed.
 * @slot help-tip - Custom help-tip content.
 * @slot help-text - Custom help-text content.
 * @slot label - The radio group label. Required for proper accessibility. Alternatively, you can use the label attribute.
 *
 * @event ev-change - Emitted when the radio group's selected value changes.
 * @event ev-input - Emitted when the radio group receives user input.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart form-control - The form control that wraps the label, input, and help-text.
 * @csspart form-control-label - The label's wrapper.
 * @csspart form-control-input - The input's wrapper.
 * @csspart form-control-help-text - The help text's wrapper.
 * @csspart button-group - The button group that wraps radio buttons.
 * @csspart button-group__base - The button group's `base` part.
 */
export default class LynkRadioGroup extends LynkElement implements LynkFormControl {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-button-group': typeof LynkButtonGroup;
        'lynk-tooltip': typeof LynkTooltip;
    };
    protected readonly formControlController: FormControlController;
    private readonly hasSlotController;
    private customValidityMessage;
    private validationTimeout;
    defaultSlot: HTMLSlotElement;
    validationInput: HTMLInputElement;
    private hasButtonGroup;
    private errorMessage;
    defaultValue: string;
    /**
     * The radio group's label. Required for proper accessibility. If you need to display HTML, use the `label` slot
     * instead.
     */
    label: string;
    /** The input's help text. If you need to display HTML, you can use the `help-text` slot instead. */
    helpText: string;
    /** The help tooltip appended to the label. Alternatively, you can use the help-tip slot. */
    helpTip: string;
    /** The name of the radio group, submitted as a name/value pair with form data. */
    name: string;
    /** The current value of the radio group, submitted as a name/value pair with form data. */
    value: string;
    /** The radio group's size. This size will be applied to all child radios and radio buttons. */
    size: 'small' | 'medium' | 'large';
    /**
     * By default, form controls are associated with the nearest containing `<form>` element. This attribute allows you
     * to place the form control outside of a form and associate it with the form that has this `id`. The form must be in
     * the same document or shadow root for this to work.
     */
    form: string;
    /** Ensures a child radio is checked before allowing the containing form to submit. */
    required: boolean;
    /** The input's feedback status using manual validation. Alternatively, you can use the invalid attribute */
    state: 'error' | 'warning' | 'success' | 'default';
    /** Gets the validity state object */
    get validity(): ValidityState;
    /** Gets the validation message */
    get validationMessage(): string;
    connectedCallback(): void;
    firstUpdated(): void;
    private getAllRadios;
    private handleRadioClick;
    private handleKeyDown;
    private handleLabelClick;
    private handleInvalid;
    private syncRadioElements;
    private syncRadios;
    private updateCheckedRadio;
    handleSizeChange(): void;
    handleValueChange(): void;
    /** Checks for validity but does not show a validation message. Returns `true` when valid and `false` when invalid. */
    checkValidity(): boolean;
    /** Gets the associated form, if one exists. */
    getForm(): HTMLFormElement | null;
    /** Checks for validity and shows the browser's validation message if the control is invalid. */
    reportValidity(): boolean;
    /** Sets a custom validation message. Pass an empty string to restore validity. */
    setCustomValidity(message?: string): void;
    /** Sets focus on the radio-group. */
    focus(options?: FocusOptions): void;
    render(): import("lit").TemplateResult<1>;
}
