import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import LynkTooltip from '../tooltip/tooltip.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Nav items allow the user to navigate or trigger actions from within a navigation menu.
 * @documentation https://lynk.design/components/nav-item
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 * @dependency lynk-tooltip
 *
 * @event ev-expand - Emitted when the nav item expands.
 * @event ev-after-expand - Emitted after the nav item expands and all animations are complete.
 * @event ev-collapse - Emitted when the nav item collapses.
 * @event ev-after-collapse - Emitted after the nav item collapses and all animations are complete.
 *
 * @slot - The nav item's label.
 * @slot prefix - Used to prepend an icon or similar element to the nav item.
 * @slot suffix - Used to append an icon or similar element to the nav item.
 * @slot children - Used to nest nav items under a nav item.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart prefix - The prefix container.
 * @csspart label - The nav item label.
 * @csspart suffix - The suffix container.
 *
 * @cssproperty [--hover-bg-color=var(--lynk-color-gray-a25)] - Customize the hover styles.
 * @cssproperty [--selected-bg-color=var(--lynk-color-primary-700)] - Customize the selected styles.
 * @cssproperty [--selected-color=var(--lynk-color-gray-a25)] - Customize the selected styles.
 * @cssproperty [--border-radius=var(--lynk-border-radius-medium)] - Customize the border radius.
 */
export default class LynkNavItem extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon': typeof LynkIcon;
        'lynk-tooltip': typeof LynkTooltip;
    };
    static isTreeItem(node: Node): boolean;
    private readonly localize;
    private cachedTextLabel;
    private childItems;
    isParent: boolean;
    isChild: boolean;
    loading: boolean;
    depth: number;
    squished: boolean;
    title: string;
    /** An optional name for the button. Ignored when `href` is set. */
    name: string;
    /** A unique value to store in the nav item. This can be used as a way to identify nav items when selected. */
    value: string;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target?: '_blank' | '_parent' | '_self' | '_top';
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download?: string;
    /** Draws the nav item in a highlighted or active state. */
    selected: boolean;
    /** Displays nested child nav-items if slotted  */
    expanded: boolean;
    /** Draws the nav item in a disabled state. */
    disabled: boolean;
    /**
     * Disables the label and replaces with a tooltip.
     */
    noLabel: boolean;
    defaultSlot: HTMLSlotElement;
    childrenSlot: HTMLSlotElement;
    navItem: HTMLElement;
    childrenContainer: HTMLDivElement;
    connectedCallback(): void;
    firstUpdated(): void;
    /** Simulates a click on the nav item. */
    click(): void;
    private animateCollapse;
    private animateExpand;
    private isNestedItem;
    private handleChildrenSlotChange;
    protected get hasChildren(): boolean;
    private getDepth;
    /** Returns a text label based on the contents of the menu item's default slot. */
    getTextLabel(): string;
    handleDisabledChange(): void;
    handleExpandedChange(): void;
    handleExpandAnimation(): void;
    handleSquished(): void;
    protected handleClick(event: MouseEvent): void;
    private handleDefaultSlotChange;
    /** Gets all the nested tree items in this node. */
    getChildrenItems({ includeDisabled }?: {
        includeDisabled?: boolean;
    }): LynkNavItem[];
    render(): import("lit").TemplateResult;
}
