import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Panels are lightweight content containers that may either stand alone or be grouped together to form an [Accordion](/components/accordion).
 * @documentation https://lynk.design/components/panel
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @slot - The panels' content.
 * @slot heading - The panels' heading. Alternatively, you can use the `heading` attribute.
 * @slot prefix - The panels' summary prefix `<slot>`.
 * @slot suffix - The panels' summary suffix `<slot>`.
 * @slot expand-icon - The expand icon's `<slot>`.
 * @slot collapse-icon - The collapse icon's `<slot>`.
 * @slot footer - The panels' footer `<slot>`.
 *
 * @event ev-expand - Emitted when the panel expands.
 * @event ev-after-expand - Emitted after the panel expands and all animations are complete.
 * @event ev-collapse - Emitted when the panel closes.
 * @event ev-after-collapse - Emitted after the panel closes and all animations are complete.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart header - The panel header area.
 * @csspart heading - The panel heading.
 * @csspart prefix - The panel header prefix area.
 * @csspart suffix - The panel header suffix area.
 * @csspart toggle-icon - The expand/collapse toggle icon in the header.
 * @csspart content - The panel content.
 * @csspart footer - The panel footer.
 *
 * @cssproperty --background-color - The panels background color
 * @cssproperty --spacing - The amount of padding to use for the header, body, and footer.
 * @cssproperty --border-color - Apply a panel border of your choosing.
 * @cssproperty --border-radius - The panels border radius.
 *
 * @animation panel.expand - The animation to use when expanding the panel. You can use `height: auto` with this animation.
 * @animation panel.collapse - The animation to use when collapsing the panel. You can use `height: auto` with this animation.
 */
export default class LynkPanel extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-popup': typeof LynkIcon;
    };
    panel: HTMLElement;
    header: HTMLElement;
    body: HTMLElement;
    toggleIconSlot: HTMLSlotElement;
    private readonly hasSlotController;
    private readonly localize;
    /** Indicates whether or not the panel contents are visible. You can use this in lieu of the expand/collapse methods. */
    expanded: boolean;
    /** Allow the panel contents to be toggled and enable supporting toggle controls */
    accordion: boolean;
    /** Disables an accordion panel so it can't be toggled. */
    disabled: boolean;
    /** The heading to show in the panel header. If you need to display HTML, use the `heading` slot instead. */
    heading: string;
    /** The trigger that will expand/collapse an accordion panel. */
    toggleTrigger: 'header' | 'heading' | 'icon' | 'none';
    /** Hide suffix when accordion is collapsed. */
    toggleSuffix: boolean;
    /** The placement of the toggle icon in the header. */
    toggleIconPlacement: 'start' | 'end' | 'hidden';
    /**
     * Disables the header. This will also remove the default toggle-icon, so please ensure you provide an easy,
     * accessible way for users to toggle the panel if using as part of an accordion.
     */
    noHeader: boolean;
    connectedCallback(): void;
    firstUpdated(): void;
    private hasParentAccordion;
    private handleToggleTriggerClick;
    private handlePrefixSuffixClick;
    private handlePrefixSuffixKeyDown;
    private handleHeaderKeyDown;
    handleExpandedChange(): Promise<void>;
    /** Shows the panel. */
    expand(): Promise<void>;
    /** Hides the panel */
    collapse(): Promise<void>;
    render(): import("lit").TemplateResult<1>;
}
