import LynkElement from '../../internal/lynk-element.js';
import LynkPopup from '../popup/popup.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Popover's display rich content in a "pop over" panel to add additional information or functionality when a user interacts with a triggering element.
 * @documentation https://lynk.design/components/popover
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-popup
 *
 * @slot - The popover's content.
 * @slot label - The dialog's label. Alternatively, you can use the label prop.
 * @slot trigger - The popover's trigger, usually a `<lynk-button>` element.
 * @slot footer - The dialog's footer, usually one or more buttons representing various options.
 *
 * @event ev-show - Emitted when the popover opens.
 * @event ev-after-show - Emitted after the popover opens and all animations are complete.
 * @event ev-hide - Emitted when the popover closes.
 * @event ev-after-hide - Emitted after the popover closes and all animations are complete.
 *
 * @cssproperty --width - The preferred width of the popover. Defaults to 320px or 20rem.
 * @cssproperty --max-width - The max width of the popover as determined by its contents. Defaults to 480px or 30rem.
 * @cssproperty --header-spacing - The amount of padding to use for the header.
 * @cssproperty --body-spacing - The amount of padding to use for the body.
 * @cssproperty --footer-spacing - The amount of padding to use for the footer.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart trigger - The container that wraps the trigger.
 * @csspart panel - The panel that gets shown when the popover is open.
 *
 * @animation popover.show - The animation to use when showing the popover.
 * @animation popover.hide - The animation to use when hiding the popover.
 */
export default class LynkPopover extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-popup': typeof LynkPopup;
    };
    popup: LynkPopup;
    trigger: HTMLSlotElement;
    panel: HTMLElement;
    private readonly hasSlotController;
    private readonly localize;
    /** Indicates whether or not the popover is open. You can use this in lieu of the show/hide methods. */
    open: boolean;
    /**
     * The popover's label as displayed in the header. You should always include a relevant label even when using
     * `no-header`, as it is required for proper accessibility.
     */
    label: string;
    /**
     * Disables the header. This will also remove the default close button, so please ensure you provide an easy,
     * accessible way for users to dismiss the popover.
     */
    noHeader: boolean;
    /**
     * Hides the arrow.
     */
    noArrow: boolean;
    /**
     * Hide the popover by clicking outside the panel.
     */
    clickToHide: boolean;
    /**
     * The preferred placement of the popover panel. Note that the actual placement may vary as needed to keep the panel
     * inside of the viewport.
     */
    placement: 'top' | 'top-start' | 'top-end' | 'bottom' | 'bottom-start' | 'bottom-end' | 'right' | 'right-start' | 'right-end' | 'left' | 'left-start' | 'left-end';
    /** Disables the popover so the panel will not open. */
    disabled: boolean;
    /** The popover will close when the user interacts outside of this element (e.g. clicking). */
    containingElement?: HTMLElement;
    /** The distance in pixels from which to offset the panel away from its trigger. */
    distance: number;
    /** The distance in pixels from which to offset the panel along its trigger. */
    skidding: number;
    /** Display the popover component as a block instead of inline-block. */
    block: boolean;
    /**
     * Enable this option to prevent the panel from being clipped when the component is placed inside a container with
     * `overflow: auto|scroll`.
     */
    hoist: boolean;
    connectedCallback(): void;
    firstUpdated(): void;
    disconnectedCallback(): void;
    focusOnTrigger(): void;
    handleKeyDown(event: KeyboardEvent): void;
    handleDocumentKeyDown(event: KeyboardEvent): void;
    handleDocumentMouseDown(event: MouseEvent): void;
    handleTriggerClick(): void;
    handleTriggerKeyDown(event: KeyboardEvent): void;
    handleTriggerKeyUp(event: KeyboardEvent): void;
    handleTriggerSlotChange(): void;
    updateAccessibleTrigger(): void;
    /** Shows the popover panel. */
    show(): Promise<void>;
    /** Hides the popover panel */
    hide(): Promise<void>;
    /**
     * Instructs the popover menu to reposition. Useful when the position or size of the trigger changes when the menu
     * is activated.
     */
    reposition(): void;
    addOpenListeners(): void;
    removeOpenListeners(): void;
    handleOpenChange(): Promise<void>;
    render(): import("lit").TemplateResult<1>;
}
