import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import LynkSpinner from '../spinner/spinner.component.js';
import type { CSSResultGroup } from 'lit';
import type { LynkFormControl } from '../../internal/lynk-element.js';
/**
 * @summary Buttons represent actions that are available to the user.
 * @documentation https://lynk.design/components/button
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 * @dependency lynk-spinner
 *
 * @event ev-blur - Emitted when the button loses focus.
 * @event ev-click - Emitted when the button is clicked.
 * @event ev-focus - Emitted when the button gains focus.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied..
 *
 * @slot - The button's label.
 * @slot prefix - Used to prepend an icon or similar element to the button.
 * @slot suffix - Used to append an icon or similar element to the button.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart prefix - The prefix slot's container.
 * @csspart label - The button's label.
 * @csspart suffix - The suffix slot's container.
 * @csspart caret - The button's caret.
 */
export default class LynkButton extends LynkElement implements LynkFormControl {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon': typeof LynkIcon;
        'lynk-spinner': typeof LynkSpinner;
    };
    private readonly formControlController;
    private readonly hasSlotController;
    private readonly localize;
    button: HTMLButtonElement | HTMLLinkElement;
    private hasFocus;
    invalid: boolean;
    title: string;
    /** The button's color. */
    color: 'default' | 'primary' | 'accent' | 'success' | 'neutral' | 'warning' | 'danger' | 'info' | 'text';
    /** The button's size. */
    size: 'tiny' | 'small' | 'medium' | 'large';
    /** Display the button component as a block instead of inline-block. */
    block: boolean;
    /** Draws the button with a caret for use with dropdowns, popovers, etc. */
    caret: boolean;
    /** Disables the button. */
    disabled: boolean;
    /** Draws the button in a thinking state. */
    thinking: boolean;
    /** Draws an outlined button. */
    outline: boolean;
    /** Draws an button without borders and background. */
    stealth: boolean;
    /** Draws a pill-style button with rounded edges. */
    pill: boolean;
    /**
     * Draws a circular icon button. When this attribute is present, the button expects a single `<lynk-icon>` in the
     * default slot.
     */
    circle: boolean;
    /**
     * Draws a square icon button. When this attribute is present, the button expects a single `<lynk-icon>` in the
     * default slot.
     */
    square: boolean;
    /**
     * The type of button. When the type is `submit`, the button will submit the surrounding form. Note that the default
     * value is `button` instead of `submit`, which is opposite of how native `<button>` elements behave.
     */
    type: 'button' | 'submit' | 'reset';
    /**
     * The name of the button, submitted as a name/value pair with form data, but only when this button is the submitter.
     * This attribute is ignored when `href` is present.
     */
    name: string;
    /**
     * The value of the button, submitted as a pair with the button's name as part of the form data, but only when this
     * button is the submitter. This attribute is ignored when `href` is present.
     */
    value: string;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target?: '_blank' | '_parent' | '_self' | '_top';
    /**
     * When using `href`, this attribute will map to the underlying link's `rel` attribute. Unlike regular links, the
     * default is `noreferrer noopener` to prevent security exploits. However, if you're using `target` to point to a
     * specific tab/window, this will prevent that from working correctly. You can remove or change the default value by
     * setting the attribute to an empty string or a value of your choice, respectively.
     */
    rel: string;
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download?: string;
    /**
     * The "form owner" to associate the button with. If omitted, the closest containing form will be used instead. The
     * value of this attribute must be an id of a form in the same document or shadow root as the button.
     */
    form: string;
    /** Used to override the form owner's `action` attribute. */
    formAction: string;
    /** Used to override the form owner's `enctype` attribute.  */
    formEnctype: 'application/x-www-form-urlencoded' | 'multipart/form-data' | 'text/plain';
    /** Used to override the form owner's `method` attribute.  */
    formMethod: 'post' | 'get';
    /** Used to override the form owner's `novalidate` attribute. */
    formNoValidate: boolean;
    /** Used to override the form owner's `target` attribute. */
    formTarget: '_self' | '_blank' | '_parent' | '_top' | string;
    /** Used to override the default event bubbling. */
    noBubble: boolean;
    /** Gets the validity state object */
    get validity(): ValidityState;
    /** Gets the validation message */
    get validationMessage(): string;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    private handleBlur;
    private handleFocus;
    private handleClick;
    private handleHostClick;
    private handleInvalid;
    private isButton;
    private isLink;
    handleDisabledChange(): void;
    /** Simulates a click on the button. */
    click(): void;
    /** Sets focus on the button. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the button. */
    blur(): void;
    /** Checks for validity but does not show the browser's validation message. */
    checkValidity(): boolean;
    /** Gets the associated form, if one exists. */
    getForm(): HTMLFormElement | null;
    /** Checks for validity and shows the browser's validation message if the control is invalid. */
    reportValidity(): boolean;
    /** Sets a custom validation message. Pass an empty string to restore validity. */
    setCustomValidity(message: string): void;
    render(): import("lit").TemplateResult;
}
